@@ -65,6 +65,7 @@ struct _GstIdentity {
   gboolean 	 check_imperfect_timestamp;
   gboolean 	 check_imperfect_offset;
   gboolean	 single_segment;
+  GstBufferFlags drop_buffer_flags;
   GstClockTime   prev_timestamp;
   GstClockTime   prev_duration;
   guint64        prev_offset;
@@ -75,6 +76,7 @@ struct _GstIdentity {
   GstClockTime   upstream_latency;
   GCond          blocked_cond;
   gboolean       blocked;
+  GstClockTimeDiff  ts_offset;
 };
 
 struct _GstIdentityClass {
